==> kolourpaint-17.03.80.tar.xz: kolourpaint-17.03.80/commands/imagelib/effects/kpEffectInvertCommand.h <==

/*
   Copyright (c) 2003-2007 Clarence Dang <dang@kde.org>
   All rights reserved.

   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
   are met:

   1. Redistributions of source code must retain the above copyright
      notice, this list of conditions and the following disclaimer.
   2. Redistributions in binary form must reproduce the above copyright
      notice, this list of conditions and the following disclaimer in the
      documentation and/or other materials provided with the distribution.

   THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
   IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
   IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
   INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
   NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
   DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
   THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
   (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
   THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/


#ifndef kpEffectInvertCommand_H
#define kpEffectInvertCommand_H


#include "kpEffectCommandBase.h"
#include "imagelib/kpImage.h"



class kpEffectInvertCommand : public kpEffectCommandBase
{
public:
    kpEffectInvertCommand (int channels,
                           bool actOnSelection,
                           kpCommandEnvironment *environ);
    kpEffectInvertCommand (bool actOnSelection,
                           kpCommandEnvironment *environ);
    virtual ~kpEffectInvertCommand ();


    //
    // kpEffectCommandBase interface
    //

public:
    virtual bool isInvertible () const { return true; }

protected:
    virtual kpImage applyEffect (const kpImage &image);

    int m_channels;
};


#endif  // kpEffectInvertCommand_H

==> kolourpaint-22.04.1.tar.xz: kolourpaint-22.04.1/commands/imagelib/effects/kpEffectInvertCommand.h <==

/*
   Copyright (c) 2003-2007 Clarence Dang <dang@kde.org>
   All rights reserved.

   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
   are met:

   1. Redistributions of source code must retain the above copyright
      notice, this list of conditions and the following disclaimer.
   2. Redistributions in binary form must reproduce the above copyright
      notice, this list of conditions and the following disclaimer in the
      documentation and/or other materials provided with the distribution.

   THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
   IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
   IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
   INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
   NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
   DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
   THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
   (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
   THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/


#ifndef kpEffectInvertCommand_H
#define kpEffectInvertCommand_H


#include "kpEffectCommandBase.h"
#include "imagelib/kpImage.h"



class kpEffectInvertCommand : public kpEffectCommandBase
{
public:
    kpEffectInvertCommand (int channels,
                           bool actOnSelection,
                           kpCommandEnvironment *environ);
    kpEffectInvertCommand (bool actOnSelection,
                           kpCommandEnvironment *environ);
    ~kpEffectInvertCommand () override;


    //
    // kpEffectCommandBase interface
    //

public:
    bool isInvertible () const override { return true; }

protected:
    kpImage applyEffect (const kpImage &image) override;

    int m_channels;
};


#endif  // kpEffectInvertCommand_H
